diff mbox series

[ndctl,2/2] scripts: update release scripts for meson

Message ID 20220829234157.101085-3-vishal.l.verma@intel.com
State Accepted
Commit 43730b622d2d159d5b2edf28e871fd1bb9b24f3b
Headers show
Series misc RPM / release scripts fixes | expand

Commit Message

Verma, Vishal L Aug. 29, 2022, 11:41 p.m. UTC
Update scripts/prepare-release and scripts/do_abidiff to use meson, and
change the expected branch name from 'master' to 'main'.

Signed-off-by: Vishal Verma <vishal.l.verma@intel.com>
---
 scripts/do_abidiff         | 14 ++++++--------
 scripts/prepare-release.sh | 24 ++++++++++++------------
 2 files changed, 18 insertions(+), 20 deletions(-)
diff mbox series

Patch

diff --git a/scripts/do_abidiff b/scripts/do_abidiff
index ec3e344..cb60e23 100755
--- a/scripts/do_abidiff
+++ b/scripts/do_abidiff
@@ -17,13 +17,11 @@  build_rpm()
 	local version=""
 
 	# prepare ndctl tree
-	rm -rf results_ndctl
+	rm -rf results_ndctl build
 	git checkout -b rel_${ref} $ref
-	./autogen.sh
-	./configure CFLAGS='-g -O2' --prefix=/usr --sysconfdir=/etc --libdir=/usr/lib64
-	make clean
-	make rhel/ndctl.spec
-	cp rhel/ndctl.spec .
+	meson setup build
+	meson compile -C build rhel/ndctl.spec
+	cp build/rhel/ndctl.spec .
 
 	# build and copy RPMs
 	version="$(./git-version)"
@@ -46,8 +44,8 @@  build_rpm()
 do_diff()
 {
 	local pkg="$1"
-	local old_base="$(find . -regex "./release/rel_${old}/${pkg}-[0-9]+.*" | head -1)"
-	local new_base="$(find . -regex "./release/rel_${new}/${pkg}-[0-9]+.*" | head -1)"
+	local old_base="$(find . -regex "./release/rel_${old}/${pkg}[-cli]*-[0-9]+.*" | head -1)"
+	local new_base="$(find . -regex "./release/rel_${new}/${pkg}[-cli]*-[0-9]+.*" | head -1)"
 	local old_dev="$(find . -regex "./release/rel_${old}/${pkg}-devel-[0-9]+.*" | head -1)"
 	local new_dev="$(find . -regex "./release/rel_${new}/${pkg}-devel-[0-9]+.*" | head -1)"
 	local old_lib="$(find . -regex "./release/rel_${old}/${pkg}-libs-[0-9]+.*" | head -1)"
diff --git a/scripts/prepare-release.sh b/scripts/prepare-release.sh
index 8901b50..c8f54dc 100755
--- a/scripts/prepare-release.sh
+++ b/scripts/prepare-release.sh
@@ -6,7 +6,7 @@ 
 
 # Notes:
 #  - Checkout to the appropriate branch beforehand
 #     master - for major release
 #     ndctl-xx.y - for fixup release
 #    This is important for generating the shortlog
 #  - Add a temporary commit that updates the libtool versions as needed.
@@ -50,9 +50,9 @@  check_branch()
 			err "expected an ndctl-xx.y branch for fixup release"
 		fi
 	else
-		# major release, expect master branch
-		if ! grep -Eq "^master$" <<< "$cur"; then
-			err "expected master branch for a major release"
+		# major release, expect main branch
+		if ! grep -Eq "^main$" <<< "$cur"; then
+			err "expected main branch for a major release"
 		fi
 	fi
 	if ! git diff-index --quiet HEAD --; then
@@ -99,7 +99,7 @@  gen_lists()
 	c_count=$(git log --pretty=format:"%s" "$range" | wc -l)
 }
 
 # Check libtool versions in Makefile.am.in
 # $1: lib name (currently libndctl, libdaxctl, or libcxl)
 check_libtool_vers()
 {
@@ -107,13 +107,13 @@  check_libtool_vers()
 	local lib_u="${lib^^}"
 	local libdir="${lib##lib}/lib/"
 	local symfile="${libdir}/${lib}.sym"
-	local last_cur=$(git show $last_ref:Makefile.am.in | grep -E "^${lib_u}_CURRENT" | cut -d'=' -f2)
-	local last_rev=$(git show $last_ref:Makefile.am.in | grep -E "^${lib_u}_REVISION" | cut -d'=' -f2)
-	local last_age=$(git show $last_ref:Makefile.am.in | grep -E "^${lib_u}_AGE" | cut -d'=' -f2)
+	local last_cur=$(git show $last_ref:meson.build | grep -E "^${lib_u}_CURRENT" | cut -d'=' -f2)
+	local last_rev=$(git show $last_ref:meson.build | grep -E "^${lib_u}_REVISION" | cut -d'=' -f2)
+	local last_age=$(git show $last_ref:meson.build | grep -E "^${lib_u}_AGE" | cut -d'=' -f2)
 	local last_soname=$((last_cur - last_age))
-	local next_cur=$(git show HEAD:Makefile.am.in | grep -E "^${lib_u}_CURRENT" | cut -d'=' -f2)
-	local next_rev=$(git show HEAD:Makefile.am.in | grep -E "^${lib_u}_REVISION" | cut -d'=' -f2)
-	local next_age=$(git show HEAD:Makefile.am.in | grep -E "^${lib_u}_AGE" | cut -d'=' -f2)
+	local next_cur=$(git show HEAD:meson.build | grep -E "^${lib_u}_CURRENT" | cut -d'=' -f2)
+	local next_rev=$(git show HEAD:meson.build | grep -E "^${lib_u}_REVISION" | cut -d'=' -f2)
+	local next_age=$(git show HEAD:meson.build | grep -E "^${lib_u}_AGE" | cut -d'=' -f2)
 	local next_soname=$((next_cur - next_age))
 	local soname_diff=$((next_soname - last_soname))
 
@@ -195,6 +195,6 @@  sed -i -e "s/DEF_VER=[0-9]\+.*/DEF_VER=${next_ref#v}/" git-version
 echo "Ready to release ndctl-$next_ref with $c_count new commits."
 echo "Add git-version to the top commit to get the updated version."
 echo "Use release/commits and release/shortlog to compose the release message"
-echo "The release commit typically contains the Makefile.am.in libtool version"
+echo "The release commit typically contains the meson.build libtool version"
 echo "update, and the git-version update."
 echo "Finally, ensure the release commit as well as the tag are PGP signed."
@@ -6,7 +6,7 @@ 
 # Notes:
 #  - Checkout to the appropriate branch beforehand
-#     master - for major release
+#     main - for major release
 #     ndctl-xx.y - for fixup release
 #    This is important for generating the shortlog
@@ -99,7 +99,7 @@  gen_lists()
 }
 
-# Check libtool versions in Makefile.am.in
+# Check libtool versions in meson.build
 # $1: lib name (currently libndctl, libdaxctl, or libcxl)
 check_libtool_vers()